@@ -19,7 +19,7 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-__VERSION__='17.10.7'
+__VERSION__='18.04.1'
 
 import gc
 import gi
@@ -704,19 +704,21 @@ class MenuWin( object ):
         else:
             self.button_icon.show()
         # This code calculates width and height for the button_box
-        # and takes the orientation in account
+        # and takes the orientation and scale factor in account
         bi_req = self.button_icon.get_preferred_size()[1]
+        bi_scale = self.button_icon.get_scale_factor()
         sl_req = self.systemlabel.get_preferred_size()[1]
+        sl_scale = self.systemlabel.get_scale_factor()
         if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
             if self.hideIcon:
-                self.applet.set_size_request( sl_req.width + 2, bi_req.height )
+                self.applet.set_size_request( sl_req.width / sl_scale + 2, bi_req.height )
             else:
-                self.applet.set_size_request( sl_req.width + bi_req.width + 5, bi_req.height )
+                self.applet.set_size_request( sl_req.width / sl_scale + bi_req.width / bi_scale + 5, bi_req.height )
         else:
             if self.hideIcon:
-                self.applet.set_size_request( bi_req.width, sl_req.height + 2 )
+                self.applet.set_size_request( bi_req.width, sl_req.height / sl_scale + 2 )
             else:
-                self.applet.set_size_request( bi_req.width, sl_req.height + bi_req.height + 5 )
+                self.applet.set_size_request( bi_req.width, sl_req.height / sl_scale + bi_req.height / bi_scale + 5 )
 
     def reloadSettings( self, *args ):
         self.loadSettings()
